@@ -1,15 +1,16 @@
 package Test::Spy;
-$Test::Spy::VERSION = '0.002';
+$Test::Spy::VERSION = '0.003';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo;
 use Mooish::AttributeBuilder;
-use Util::H2O;
 use Carp qw(croak);
 
 use Test::Spy::Method;
+use Test::Spy::Observer;
+use Test::Spy::Object;
 
 has param 'interface' => (
 	isa => sub {
@@ -34,6 +35,11 @@ has option 'context' => (
 	clearer => 1,
 );
 
+has option 'base' => (
+	writer => 1,
+	trigger => '_clear_object',
+);
+
 with qw(Test::Spy::Interface);
 
 sub _no_method
@@ -50,35 +56,21 @@ sub _build_object
 	my %methods = %{$self->_mocked_subs};
 	my %init_hash;
 
-	for my $method_name (keys %methods) {
-		my $method = $methods{$method_name};
-		$init_hash{$method_name} = sub {
-			return $method->_called(@_);
-		};
-	}
+	my $base = $self->has_base
+		? ref $self->base ? $self->base : $self->base->new
+		: undef;
 
-	my $interface = $self->interface;
-	if ($interface ne 'strict') {
-		$init_hash{AUTOLOAD} = sub {
-			our $AUTOLOAD;
-			my $method = $AUTOLOAD;
-			$method =~ m/(\w+)$/;
-
-			warn "method '$1' was called on Test::Spy->object"
-				if $interface eq 'warn';
-
-			return undef;
-		};
-	}
-
-	return h2o -meth, \%init_hash;
+	return Test::Spy::Object->_new(
+		%{$base // {}},
+		__base => $base,
+		__spy => $self,
+	);
 }
 
 sub add_method
 {
 	my ($self, $method_name, @returns) = @_;
 
-	$self->_clear_object;
 	my $method = $self->_mocked_subs->{$method_name} = Test::Spy::Method->new(method_name => $method_name);
 
 	if (@returns) {
@@ -88,6 +80,13 @@ sub add_method
 	return $method;
 }
 
+sub add_observer
+{
+	my ($self, $method_name) = @_;
+
+	return $self->_mocked_subs->{$method_name} = Test::Spy::Observer->new(method_name => $method_name);
+}
+
 sub method
 {
 	my ($self, $method_name) = @_;
